import{b,T as f}from"./router-C1hHJqQH.js";import{e as m,b as u,l as d,n as i,j as y,g as r,p as s,w as t,B as g,R as l,S as o,q as p,ai as _}from"./jwt-decode.esm-CMj0qxed.js";import{A as k}from"./index-DEMl_2bX.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="62e8d4a9-6f9b-483c-9815-bf2b06a71d25",e._sentryDebugIdIdentifier="sentry-dbid-62e8d4a9-6f9b-483c-9815-bf2b06a71d25")}catch{}})();const M=m({__name:"BillingAlert",props:{organizationId:{},billingMetadata:{}},setup(e){const a=e,n=u(()=>a.billingMetadata?.messageCTA??d.translate("i18n_billingalert_contact_us")),c=()=>{b.showNewMessage(d.translate("i18n_billingalert_help_message")),f.billingAlertCtaClicked(a.organizationId,n.value)};return(C,w)=>e.billingMetadata?.message?(r(),i(s(k),{key:0,type:"error"},{message:t(()=>[p(s(_),{type:"secondary"},{default:t(()=>[l(o(e.billingMetadata?.message),1)]),_:1})]),action:t(()=>[e.billingMetadata?.messageLink?(r(),i(s(g),{key:0,type:"primary",target:"_blank",href:e.billingMetadata.messageLink},{default:t(()=>[l(o(n.value),1)]),_:1},8,["href"])):(r(),i(s(g),{key:1,type:"primary",onClick:c},{default:t(()=>[l(o(n.value),1)]),_:1}))]),_:1})):y("",!0)}});export{M as _};
//# sourceMappingURL=BillingAlert.vue_vue_type_script_setup_true_lang-b4dt0jmm.js.map
