import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-BiOV2Lqv.js";import{A as h}from"./constants-BuCkByzO.js";import{e as v,b as w,aj as A,l as o,f as B,q as d,n as m,j as p,w as t,p as e,al as I,b6 as _,B as x,R as a,S as u,k as C,b7 as N,ae as S,g as c,aM as T}from"./jwt-decode.esm-CMj0qxed.js";import{u as D}from"./workspaceStore-BpM_nIpQ.js";import{C as E}from"./index-Dtwf37v1.js";import"./logo-BiWG9_W5.js";import"./Logo-DAPfDL_2.js";import"./userStore-JzsU92N_.js";import"./runnerData-CxVMN4tJ.js";import"./url-CV3yU0Fs.js";import"./colorHelpers-CKFPtJNj.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new H().stack;i&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[i]="dff6cbbb-7d14-43d8-922b-1bd28f359df1",r._sentryDebugIdIdentifier="sentry-dbid-dff6cbbb-7d14-43d8-922b-1bd28f359df1")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},j=v({__name:"Error",setup(r){const i=A(),b=S(),f=D(),g=w(()=>f.state.workspace?.name??f.state.workspace?.brandName),n=w(()=>{const{status:l}=i.params;switch(l){case"404":return{status:l,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:l,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),y=()=>{b.push({name:"playerHome"})};return(l,s)=>(c(),B("div",R,[d(e(I),null,{default:t(()=>[a(u(n.value.title),1)]),_:1}),d(e(_),{class:"message"},{default:t(()=>[a(u(n.value.message),1)]),_:1}),n.value.action?(c(),m(e(x),{key:0,type:"link",onClick:y},{default:t(()=>[a(u(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(c(),m(e(E),{key:1,bordered:!1,class:"card"},{default:t(()=>[C("div",V,[d(k,{style:{"margin-bottom":"10px"}}),d(e(_),null,{default:t(()=>[a("This page is part of "+u(g.value?`the ${g.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(f).state.workspace?(c(),m(e(_),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),d(e(N),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}}),H=T(j,[["__scopeId","data-v-522ad0d4"]]);export{H as default};
//# sourceMappingURL=Error-C-JqLhTQ.js.map
