import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-BiOV2Lqv.js";import{B as y}from"./BaseLayout-DhQ9nj30.js";import{e as l,O as _,$ as b,aM as u,aI as v,aJ as g,g as f,f as h,k as a,F as s,M as w,ae as S,n as k,w as n,aj as I,q as i,p as $}from"./jwt-decode.esm-CMj0qxed.js";import{u as B}from"./editor-mFrGuvSs.js";import{A as L}from"./index-CP9ilNKN.js";import"./logo-BiWG9_W5.js";import"./Logo-DAPfDL_2.js";import"./ts.worker-CXGQk1hm.js";import"./workspaceStore-BpM_nIpQ.js";import"./userStore-JzsU92N_.js";import"./runnerData-CxVMN4tJ.js";import"./url-CV3yU0Fs.js";import"./colorHelpers-CKFPtJNj.js";import"./useCodebaseEvents-5pjlBala.js";import"./contracts.generated-CEGYE42M.js";import"./files-ZRC9S6Yb.js";import"./PhBug.vue-Db93svuM.js";import"./router-PyoVUxyw.js";import"./constants-BuCkByzO.js";import"./index-ChgvlYjK.js";import"./index-CHbAQJtG.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="793f6590-f126-4ae1-b6d5-2bddad7fef47",e._sentryDebugIdIdentifier="sentry-dbid-793f6590-f126-4ae1-b6d5-2bddad7fef47")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),D={class:"v-spinner"};function P(e,r,o,d,p,c){return v((f(),h("div",D,[a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u(x,[["render",P],["__scopeId","data-v-224007fd"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=I(),o=S(),d=B();function p(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function c(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=c();if(!t){o.push({name:"error"});return}await d.createLogin(t).then(p),o.push({name:"editor"})}),(t,A)=>(f(),k(y,null,{navbar:n(()=>[i($(L),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[a("div",j,[i(R)])]),_:1}))}}),re=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-BNVkTPKd.js.map
