import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-DghU1eC3.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-CMj0qxed.js";import{u as a}from"./projectStore-BWN_nmRd.js";import"./router-C1hHJqQH.js";import"./ts.worker-CXGQk1hm.js";import"./fetch-Dc4k5W7i.js";import"./tables-ChrXZ9vU.js";import"./string-CO_aYvwE.js";import"./SaveButton-CJmXZnw9.js";import"./ExclamationCircleOutlined-smv89w_H.js";import"./CrudView-DK15k5Zu.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DbKeIVSb.js";import"./constants-BuCkByzO.js";import"./url-CV3yU0Fs.js";import"./PhDotsThreeVertical.vue-CuncxdqG.js";import"./index-ChgvlYjK.js";import"./asyncComputed-BRXehLE6.js";import"./PhPencil.vue-BxlC2z49.js";import"./useCodebaseEvents-5pjlBala.js";import"./contracts.generated-CEGYE42M.js";import"./index-DEMl_2bX.js";import"./project-CgMbyb8B.js";import"./organizationSwitcher-B8aspLB5.js";import"./organization-B4Ec1XDU.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="3d94f7cd-1fad-4938-9294-98c2a9e73195",o._sentryDebugIdIdentifier="sentry-dbid-3d94f7cd-1fad-4938-9294-98c2a9e73195")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),t=new e(r.projectId);return(d,c)=>(s(),n(p,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-DmRBNVXg.js.map
