import{N as c}from"./Navbar-CPjs_Hrt.js";import{e as d,aj as u,b as a,l,a2 as f,f as _,g as b,q as p,k as y,aM as I}from"./jwt-decode.esm-CMj0qxed.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-j4mR0zhQ.js";import"./LoadingOutlined-DpgFTZr3.js";import"./constants-BuCkByzO.js";import"./PhCaretDown.vue-DP0XUe8I.js";import"./PhPencilSimple.vue-BQfD5-wA.js";import"./router-C1hHJqQH.js";import"./ts.worker-CXGQk1hm.js";import"./organization-B4Ec1XDU.js";import"./tables-ChrXZ9vU.js";import"./string-CO_aYvwE.js";import"./keyboard-Cj3Eq9JL.js";import"./os-BZTmM1C_.js";import"./projectStore-BWN_nmRd.js";import"./project-CgMbyb8B.js";import"./organizationSwitcher-B8aspLB5.js";import"./cascaderStore-DBtQrgvt.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-D9HlES3Z.js";import"./member-aBXlZP5O.js";import"./index-BxpursFE.js";import"./index-Dtwf37v1.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-BidjSxuB.js";import"./PhNotePencil.vue-Da5zUlPT.js";import"./PhSignOut.vue-CkoR7qz-.js";import"./index-ChgvlYjK.js";import"./index-CHbAQJtG.js";import"./PhPlus.vue-DpL0dPAD.js";import"./omniChatStore-CMMDMpjS.js";import"./files-ZRC9S6Yb.js";import"./contracts.generated-CEGYE42M.js";import"./runnerData-CxVMN4tJ.js";import"./url-CV3yU0Fs.js";import"./colorHelpers-CKFPtJNj.js";import"./uuid-CY9ZOXh3.js";import"./PhCopySimple.vue-gYe0qW8r.js";import"./PhSparkle.vue-Ds42hbuj.js";import"./index-CP9ilNKN.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="504a696f-098f-4a90-8b4a-1df60ea4a1b6",r._sentryDebugIdIdentifier="sentry-dbid-504a696f-098f-4a90-8b4a-1df60ea4a1b6")}catch{}})();const g={class:"console-layout"},v={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",v,[p(e)])])}}}),po=I(w,[["__scopeId","data-v-62f8634d"]]);export{po as default};
//# sourceMappingURL=ConsoleLayout-DiM-_8jD.js.map
